<?php
/**
 * Optical Lens Shop  Theme Customizer
 *
 * @package Optical Lens Shop 
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function optical_lens_shop_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'optical_lens_shop_custom_controls' );

function optical_lens_shop_customize_register( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'optical_lens_shop_Customize_partial_blogname',
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'optical_lens_shop_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'optical_lens_shop_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'Homepage Settings', 'optical-lens-shop' ),
		'priority' => 10,
	));

	// Layout
	$wp_customize->add_section( 'optical_lens_shop_left_right', array(
    	'title' => esc_html__('General Settings', 'optical-lens-shop'),
		'panel' => 'optical_lens_shop_panel_id'
	) );

	$wp_customize->add_setting('optical_lens_shop_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'optical_lens_shop_sanitize_choices'
	));
	$wp_customize->add_control(new Optical_Lens_Shop_Image_Radio_Control($wp_customize, 'optical_lens_shop_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','optical-lens-shop'),
        'description' => esc_html__('Here you can change the width layout of Website.','optical-lens-shop'),
        'section' => 'optical_lens_shop_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('optical_lens_shop_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'optical_lens_shop_sanitize_choices'
	));
	$wp_customize->add_control('optical_lens_shop_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','optical-lens-shop'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','optical-lens-shop'),
        'section' => 'optical_lens_shop_left_right',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','optical-lens-shop'),
            'Right Sidebar' => esc_html__('Right Sidebar','optical-lens-shop'),
            'One Column' => esc_html__('One Column','optical-lens-shop'),
            'Grid Layout' => esc_html__('Grid Layout','optical-lens-shop')
        ),
	) );

	$wp_customize->add_setting('optical_lens_shop_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'optical_lens_shop_sanitize_choices'
	));
	$wp_customize->add_control('optical_lens_shop_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','optical-lens-shop'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','optical-lens-shop'),
        'section' => 'optical_lens_shop_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','optical-lens-shop'),
            'Right_Sidebar' => esc_html__('Right Sidebar','optical-lens-shop'),
            'One_Column' => esc_html__('One Column','optical-lens-shop')
        ),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'optical_lens_shop_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'optical_lens_shop_customize_partial_optical_lens_shop_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'optical_lens_shop_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ) );
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','optical-lens-shop' ),
		'section' => 'optical_lens_shop_left_right'
    )));

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'optical_lens_shop_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'optical_lens_shop_customize_partial_optical_lens_shop_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'optical_lens_shop_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ) );
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','optical-lens-shop' ),
		'section' => 'optical_lens_shop_left_right'
    )));

    // Pre-Loader
	$wp_customize->add_setting( 'optical_lens_shop_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ) );
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','optical-lens-shop' ),
        'section' => 'optical_lens_shop_left_right'
    )));

	$wp_customize->add_setting('optical_lens_shop_preloader_bg_color', array(
		'default'           => '#00A3FC',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'optical_lens_shop_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'optical-lens-shop'),
		'section'  => 'optical_lens_shop_left_right',
	)));

	$wp_customize->add_setting('optical_lens_shop_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'optical_lens_shop_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'optical-lens-shop'),
		'section'  => 'optical_lens_shop_left_right',
	)));

	//Topbar
	$wp_customize->add_section( 'optical_lens_shop_header_section' , array(
  		'title' => __( 'Header Section', 'optical-lens-shop' ),
		'panel' => 'optical_lens_shop_panel_id'
	) );

	$wp_customize->add_setting( 'optical_lens_shop_topbar_hide_show',array(
    	'default' => 0,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ));
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_topbar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Topbar','optical-lens-shop' ),
      	'section' => 'optical_lens_shop_header_section'
    )));

	$wp_customize->add_setting('optical_lens_shop_topbar_text1',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('optical_lens_shop_topbar_text1',array(
		'label'	=> esc_html__('Add Topbar Text','optical-lens-shop'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'FREE WORLDWIDE SHIPPING ON ORDER FROM $200', 'optical-lens-shop' ),
        ),
		'section'=> 'optical_lens_shop_header_section',
		'type'=> 'text'
	));

    $wp_customize->add_setting('optical_lens_shop_phone_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'optical_lens_shop_sanitize_phone_number'
	));	
	$wp_customize->add_control('optical_lens_shop_phone_number',array(
		'label'	=> __('Add Phone number','optical-lens-shop'),
		'input_attrs' => array(
            'placeholder' => __( '+00 123 456 7890', 'optical-lens-shop' ),
        ),
		'section'=> 'optical_lens_shop_header_section',
		'type'=> 'text'
	));
	
	// Middle header
    $wp_customize->add_setting( 'optical_lens_shop_cart_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ));  
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_cart_hide_show',
       array(
		'label' => esc_html__( 'Show / Hide Cart','optical-lens-shop' ),
		'section' => 'optical_lens_shop_header_section'
    )));

    $wp_customize->add_setting( 'optical_lens_shop_wishlist_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ));  
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_wishlist_hide_show',
       array(
		'label' => esc_html__( 'Show / Hide Wishlist','optical-lens-shop' ),
		'section' => 'optical_lens_shop_header_section'
    )));

    $wp_customize->add_setting( 'optical_lens_shop_tracking_order_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ));  
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_tracking_order_hide_show',
       array(
		'label' => esc_html__( 'Show / Hide Tracking Order','optical-lens-shop' ),
		'section' => 'optical_lens_shop_header_section'
    )));

	$wp_customize->add_setting( 'optical_lens_shop_my_account_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ));  
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_my_account_hide_show',
       array(
		'label' => esc_html__( 'Show / Hide My Account','optical-lens-shop' ),
		'section' => 'optical_lens_shop_header_section'
    )));

	//Slider
	$wp_customize->add_section( 'optical_lens_shop_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'optical-lens-shop' ),
		'panel' => 'optical_lens_shop_panel_id'
	) );

	$wp_customize->add_setting( 'optical_lens_shop_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ));  
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','optical-lens-shop' ),
      'section' => 'optical_lens_shop_slidersettings'
    )));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('optical_lens_shop_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'optical_lens_shop_customize_partial_optical_lens_shop_slider_hide_show',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'optical_lens_shop_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'optical_lens_shop_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'optical_lens_shop_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'optical-lens-shop' ),
			'description' => __('Slider image size (1400 x 550)','optical-lens-shop'),
			'section'  => 'optical_lens_shop_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	$wp_customize->add_setting( 'optical_lens_shop_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'optical_lens_shop_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','optical-lens-shop'),
		'section' => 'optical_lens_shop_slidersettings',
		'type'  => 'text',
	) );

	//Slider height
	$wp_customize->add_setting('optical_lens_shop_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('optical_lens_shop_slider_height',array(
		'label'	=> __('Slider Height','optical-lens-shop'),
		'description'	=> __('Specify the slider height (px).','optical-lens-shop'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'optical-lens-shop' ),
        ),
		'section'=> 'optical_lens_shop_slidersettings',
		'type'=> 'text'
	)); 

	// Products Section
	$wp_customize->add_section('optical_lens_shop_products_section',array(
		'title'	=> __('Products Section','optical-lens-shop'),
		'panel' => 'optical_lens_shop_panel_id',
	));

	$wp_customize->add_setting( 'optical_lens_shop_product_hide_show',array(
	    'default' => 0,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
	));  
	$wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_product_hide_show',array(
		'label' => esc_html__( 'Show / Hide Product Section','optical-lens-shop' ),
		'section' => 'optical_lens_shop_products_section'
	)));

	$wp_customize->add_setting( 'optical_lens_shop_product_banner_page' , array(
		'default'           => '',
		'sanitize_callback' => 'optical_lens_shop_sanitize_dropdown_pages'
	));
	$wp_customize->add_control( 'optical_lens_shop_product_banner_page' , array(
		'label'    => __( 'Select Product Banner Page', 'optical-lens-shop' ),
		'section'  => 'optical_lens_shop_products_section',
		'type'     => 'dropdown-pages'
	) );

	$wp_customize->add_setting('optical_lens_shop_product_heading_product',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('optical_lens_shop_product_heading_product',array(
		'label'	=> __('Add Text','optical-lens-shop'),
		'input_attrs' => array(
            'placeholder' => __( 'Trending Product', 'optical-lens-shop' ),
        ),
		'section'=> 'optical_lens_shop_products_section',
		'type'=> 'text'
	));

	$args = array(
		'type'         => 'product',
		'child_of'     => 0,
		'parent'       => '',
		'orderby'      => 'term_group',
		'order'        => 'ASC',
		'hide_empty'   => false,
		'hierarchical' => 1,
		'number'       => '',
		'taxonomy'     => 'product_cat',
		'pad_counts'   => false
	);
 	$categories = get_categories( $args );
	$cat_posts = array();
	$i = 0;
	$cat_posts[]='Select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name; 
	}

	$wp_customize->add_setting('optical_lens_shop_product_page',array(
		'default'	=> 'select',
		'sanitize_callback' => 'optical_lens_shop_sanitize_choices',
	));
	$wp_customize->add_control('optical_lens_shop_product_page',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display Products','optical-lens-shop'),
		'section' => 'optical_lens_shop_products_section',
	));

	//Blog Post
	$wp_customize->add_panel( 'optical_lens_shop_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'optical-lens-shop' ),
		'panel' => 'optical_lens_shop_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'optical_lens_shop_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'optical-lens-shop' ),
		'panel' => 'optical_lens_shop_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('optical_lens_shop_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'optical_lens_shop_Customize_partial_optical_lens_shop_toggle_postdate', 
	));

	$wp_customize->add_setting( 'optical_lens_shop_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ) );
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','optical-lens-shop' ),
        'section' => 'optical_lens_shop_post_settings'
    )));

    $wp_customize->add_setting( 'optical_lens_shop_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ) );
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_toggle_author',array(
		'label' => esc_html__( 'Author','optical-lens-shop' ),
		'section' => 'optical_lens_shop_post_settings'
    )));

    $wp_customize->add_setting( 'optical_lens_shop_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ) );
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_toggle_comments',array(
		'label' => esc_html__( 'Comments','optical-lens-shop' ),
		'section' => 'optical_lens_shop_post_settings'
    )));

    $wp_customize->add_setting( 'optical_lens_shop_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ) );
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_toggle_time',array(
		'label' => esc_html__( 'Time','optical-lens-shop' ),
		'section' => 'optical_lens_shop_post_settings'
    )));

    $wp_customize->add_setting( 'optical_lens_shop_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
	));
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','optical-lens-shop' ),
		'section' => 'optical_lens_shop_post_settings'
    )));

    $wp_customize->add_setting( 'optical_lens_shop_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
	));
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_toggle_tags', array(
		'label' => esc_html__( 'Tags','optical-lens-shop' ),
		'section' => 'optical_lens_shop_post_settings'
    )));

    $wp_customize->add_setting( 'optical_lens_shop_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'optical_lens_shop_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'optical_lens_shop_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','optical-lens-shop' ),
		'section'     => 'optical_lens_shop_post_settings',
		'type'        => 'range',
		'settings'    => 'optical_lens_shop_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('optical_lens_shop_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('optical_lens_shop_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','optical-lens-shop'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','optical-lens-shop'),
		'section'=> 'optical_lens_shop_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('optical_lens_shop_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'optical_lens_shop_sanitize_choices'
	));
	$wp_customize->add_control('optical_lens_shop_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','optical-lens-shop'),
        'section' => 'optical_lens_shop_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','optical-lens-shop'),
            'Excerpt' => esc_html__('Excerpt','optical-lens-shop'),
            'No Content' => esc_html__('No Content','optical-lens-shop')
        ),
	) );

    // Button Settings
	$wp_customize->add_section( 'optical_lens_shop_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'optical-lens-shop' ),
		'panel' => 'optical_lens_shop_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('optical_lens_shop_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'optical_lens_shop_Customize_partial_optical_lens_shop_button_text', 
	));

    $wp_customize->add_setting('optical_lens_shop_button_text',array(
		'default'=> esc_html__('Read More','optical-lens-shop'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('optical_lens_shop_button_text',array(
		'label'	=> esc_html__('Add Button Text','optical-lens-shop'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'optical-lens-shop' ),
        ),
		'section'=> 'optical_lens_shop_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'optical_lens_shop_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'optical-lens-shop' ),
		'panel' => 'optical_lens_shop_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('optical_lens_shop_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'optical_lens_shop_Customize_partial_optical_lens_shop_related_post_title', 
	));

    $wp_customize->add_setting( 'optical_lens_shop_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ) );
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_related_post',array(
		'label' => esc_html__( 'Related Post','optical-lens-shop' ),
		'section' => 'optical_lens_shop_related_posts_settings'
    )));

    $wp_customize->add_setting('optical_lens_shop_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('optical_lens_shop_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','optical-lens-shop'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'optical-lens-shop' ),
        ),
		'section'=> 'optical_lens_shop_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('optical_lens_shop_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'optical_lens_shop_sanitize_number_absint'
	));
	$wp_customize->add_control('optical_lens_shop_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','optical-lens-shop'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'optical-lens-shop' ),
        ),
		'section'=> 'optical_lens_shop_related_posts_settings',
		'type'=> 'number'
	));

	//Responsive Media Settings
	$wp_customize->add_section('optical_lens_shop_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','optical-lens-shop'),
		'panel' => 'optical_lens_shop_panel_id',
	));

    $wp_customize->add_setting( 'optical_lens_shop_resp_slider_hide_show',array(
      	'default' => 0,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ));  
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','optical-lens-shop' ),
      	'section' => 'optical_lens_shop_responsive_media'
    )));

    $wp_customize->add_setting( 'optical_lens_shop_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ));  
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','optical-lens-shop' ),
      	'section' => 'optical_lens_shop_responsive_media'
    )));

    $wp_customize->add_setting( 'optical_lens_shop_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ));  
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','optical-lens-shop' ),
      	'section' => 'optical_lens_shop_responsive_media'
    )));

	//Footer Text
	$wp_customize->add_section('optical_lens_shop_footer',array(
		'title'	=> esc_html__('Footer Settings','optical-lens-shop'),
		'panel' => 'optical_lens_shop_panel_id',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('optical_lens_shop_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'optical_lens_shop_Customize_partial_optical_lens_shop_footer_text', 
	));
	
	$wp_customize->add_setting('optical_lens_shop_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('optical_lens_shop_footer_text',array(
		'label'	=> esc_html__('Copyright Text','optical-lens-shop'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2021, .....', 'optical-lens-shop' ),
        ),
		'section'=> 'optical_lens_shop_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('optical_lens_shop_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'optical_lens_shop_sanitize_choices'
	));
	$wp_customize->add_control(new Optical_Lens_Shop_Image_Radio_Control($wp_customize, 'optical_lens_shop_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','optical-lens-shop'),
        'section' => 'optical_lens_shop_footer',
        'settings' => 'optical_lens_shop_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting( 'optical_lens_shop_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'optical_lens_shop_switch_sanitization'
    ));  
    $wp_customize->add_control( new Optical_Lens_Shop_Toggle_Switch_Custom_Control( $wp_customize, 'optical_lens_shop_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','optical-lens-shop' ),
      	'section' => 'optical_lens_shop_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('optical_lens_shop_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'optical_lens_shop_Customize_partial_optical_lens_shop_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('optical_lens_shop_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'optical_lens_shop_sanitize_choices'
	));
	$wp_customize->add_control(new Optical_Lens_Shop_Image_Radio_Control($wp_customize, 'optical_lens_shop_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','optical-lens-shop'),
        'section' => 'optical_lens_shop_footer',
        'settings' => 'optical_lens_shop_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'optical_lens_shop_customize_register' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Optical_Lens_Shop_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Optical_Lens_Shop_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Optical_Lens_Shop_Customize_Section_Pro( $manager,'optical_lens_shop_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'Optical Lens Shop PRO', 'optical-lens-shop' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'optical-lens-shop' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/lens-wordpress-theme/'),
		) )	);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'optical-lens-shop-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'optical-lens-shop-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Optical_Lens_Shop_Customize::get_instance();